@@ -9,16 +9,16 @@ examples for writing your own callbacks at the :class:`.Callback` base class.
 from composer.callbacks.checkpoint_saver import CheckpointSaver
 from composer.callbacks.early_stopper import EarlyStopper
 from composer.callbacks.export_for_inference import ExportForInferenceCallback
-from composer.callbacks.grad_monitor import GradMonitor
 from composer.callbacks.image_visualizer import ImageVisualizer
 from composer.callbacks.lr_monitor import LRMonitor
 from composer.callbacks.memory_monitor import MemoryMonitor
 from composer.callbacks.mlperf import MLPerfCallback
+from composer.callbacks.optimizer_monitor import OptimizerMonitor
 from composer.callbacks.speed_monitor import SpeedMonitor
 from composer.callbacks.threshold_stopper import ThresholdStopper
 
 __all__ = [
-    'GradMonitor',
+    'OptimizerMonitor',
     'LRMonitor',
     'MemoryMonitor',
     'SpeedMonitor',
