@@ -7,21 +7,26 @@ from __future__ import annotations
 import collections.abc
 import contextlib
 import logging
+import textwrap
 import warnings
 from contextlib import contextmanager
-from typing import TYPE_CHECKING, Any, Callable, Dict, Iterable, Optional, Sequence, Union, cast
+from typing import TYPE_CHECKING, Any, Callable, Dict, Iterable, List, Optional, Sequence, Union, cast
 
 import torch
 import torch.nn.modules.utils
 from packaging import version
 from torch.nn.parallel import DistributedDataParallel
 from torch.optim import Optimizer
+from torch.utils.data import DataLoader, Dataset
 from torchmetrics import Metric
 
+from composer.core.data_spec import DataSpec
+from composer.core.event import Event
 from composer.core.precision import Precision
 from composer.core.serializable import Serializable
 from composer.core.time import Time, Timestamp, TimeUnit
-from composer.utils import batch_get, batch_set, dist, ensure_tuple, is_model_deepspeed
+from composer.devices import Device
+from composer.utils import batch_get, batch_set, dist, ensure_tuple, get_composer_env_dict, is_model_deepspeed
 
 if TYPE_CHECKING:
     import deepspeed
@@ -30,17 +35,19 @@ if TYPE_CHECKING:
     from composer.core.algorithm import Algorithm
     from composer.core.callback import Callback
     from composer.core.evaluator import Evaluator
+    from composer.core.passes import AlgorithmPass
+    from composer.loggers import Logger
     from composer.profiler import Profiler
 
 __all__ = ['State']
 
-logger = logging.getLogger(__name__)
+log = logging.getLogger(__name__)
 
 
 @contextmanager
 def get_fsdp_rank0_cpu_save_context(obj: torch.nn.Module):
-    if version.parse(torch.__version__) < version.parse('1.12.0'):
-        raise RuntimeError('To use FSDP with Composer, you must use torch>=1.12.0.')
+    if version.parse(torch.__version__) < version.parse('1.13.0'):
+        raise RuntimeError('To use FSDP with Composer, you must use torch>=1.13.0.')
     from torch.distributed.fsdp import FullStateDictConfig
     from torch.distributed.fsdp import FullyShardedDataParallel as FSDP
     from torch.distributed.fsdp import StateDictType
@@ -50,15 +57,15 @@ def get_fsdp_rank0_cpu_save_context(obj: torch.nn.Module):
 
 
 def get_fsdp_sharded_optim_state_dict(full_optim_state_dict: Dict[str, Any], model: torch.nn.Module):
-    if version.parse(torch.__version__) < version.parse('1.12.0'):
-        raise RuntimeError('To use FSDP with Composer, you must use torch>=1.12.0.')
+    if version.parse(torch.__version__) < version.parse('1.13.0'):
+        raise RuntimeError('To use FSDP with Composer, you must use torch>=1.13.0.')
     from torch.distributed.fsdp import FullyShardedDataParallel as FSDP
     return FSDP.scatter_full_optim_state_dict(full_optim_state_dict=full_optim_state_dict, model=model)
 
 
 def get_fsdp_full_optim_state_dict(model: torch.nn.Module, optim: torch.optim.Optimizer, rank0_only: bool = True):
-    if version.parse(torch.__version__) < version.parse('1.12.0'):
-        raise RuntimeError('To use FSDP with Composer, you must use torch>=1.12.0.')
+    if version.parse(torch.__version__) < version.parse('1.13.0'):
+        raise RuntimeError('To use FSDP with Composer, you must use torch>=1.13.0.')
     from torch.distributed.fsdp import FullyShardedDataParallel as FSDP
     return FSDP.full_optim_state_dict(model=model, optim=optim, rank0_only=rank0_only)
 
@@ -108,14 +115,17 @@ class State(Serializable):
         rank_zero_seed (int): The seed used on the rank zero process. It is assumed that each rank's seed is
             ``rank_zero_seed + dist.get_global_rank()``.
         run_name (str): The name for this training run.
+        device (Device): The device used by this process. The trainer moves the model and loaded data to this device.
         grad_accum (int, optional): The number of gradient accumulation steps to use. With this argument, micro batch
             size for each device becomes ``microbatch_size = train_batch_size / (num_devices * grad_accum)``.
         eval_batch_split (int, optional): The mirror of grad_accum for eval. With this argument, micro batch
             size for each device becomes ``microbatch_size = eval_batch_size / (num_devices * eval_batch_split)``.
-        auto_grad_accum (bool, optional): Whether automatic gradient accumulation is enabled.
-        train_dataloader (types.DataLoader, optional): Dataloader used for training
-        evaluators (Evalutor | Evaluators, optional): :class:`.Evaluator` used for evaluation.
-        dataloader (types.DataLoader, optional): The active DataLoader.
+        device_train_microbatch_size (int, optional): The microbatch size for each device during training.
+        auto_microbatching (bool, optional): Whether automatic microbatching is enabled.
+        using_device_microbatch_size (bool, optional): Whether device_train_microbatch_size is set by the user.
+        train_dataloader (Iterable, optional): Dataloader used for training
+        evaluators (Evaluator | Evaluators, optional): :class:`.Evaluator` used for evaluation.
+        dataloader (Iterable, optional): The active DataLoader.
         dataloader_len (int | Time[int], optional): The number of batches per dataloader iteration (e.g. epoch).
             The trainer will yield the first ``dataloader_len`` batches per iteration. If ``-1`` (the default),
             the entire dataloader will be iterated over.
@@ -124,6 +134,8 @@ class State(Serializable):
 
             By convention, the training dataloader is called ``'train'``. The evaluator dataloader is called
             ``'eval'``, or when multiple evaluators are used, the name of the evaluator.
+        dataset_state (Dict[str, Any], optional): Mapping of dataset split to its iteration state for resumption.
+        dataset_resumption (Dict[str, Any], optional): Mapping of dataset split to whether resumption is used.
         max_duration (str | Time, optional): The maximum duration to train for. (default: ``None``)
         precision (str | Precision): The numerical precision to use for training. See :class:`~.Precision` for
             the supported precisions.
@@ -135,10 +147,13 @@ class State(Serializable):
         algorithms (Algorithm | Sequence[Algorithm], optional): The algorithms used for training.
         callbacks (Callback | Sequence[Callback], optional): The callbacks used for training.
         deepspeed_config (Dict[str, Any], optional): The configuration dictionary for deepspeed.
+        fsdp_config (Dict[str, Any], optional): The configuration dictionary for FSDP.
 
     Attributes:
         batch (types.Batch): The batch. This will be the entire batch during the :attr:`.Event.AFTER_DATALOADER`, or a
             microbatch between :attr:`.Event.BATCH_START` and :attr:`.Event.BATCH_END`.
+        device (Device): The device used by this process. The trainer moves the model and loaded data to this device. This
+            can be used in callbacks and algorithms to move data onto the correct device.
         train_metrics (Dict[str, Metric]): The current train metrics, organized by metric name. ``train_metrics`` will be deep-copied to
             ensure that each evaluator updates only its ``train_metrics``.
 
@@ -195,6 +210,7 @@ class State(Serializable):
             before the dataloader is evaluated. The :attr:`~Timestamp.epoch` attribute for this timestamp is always
             ``0``.
         grad_accum (int): The number of gradient accumulation steps per batch.
+        device_train_microbatch_size (int): The size of each train microbatch per device.
         loss (torch.Tensor | Sequence[torch.Tensor]): The most recently computed loss.
         model (torch.nn.Module): The training model.
 
@@ -243,9 +259,10 @@ class State(Serializable):
             +-----------------------+-------------------------------------------------------------+
             | run_name              | The run name for training.                                  |
             +-----------------------+-------------------------------------------------------------+
+            | dataset_state         | The dataset iteration state.                                |
+            +-----------------------+-------------------------------------------------------------+
 
         timestamp (Timestamp): The current training timestamp.
-        train_dataloader (Iterable): The training dataloader. (May be ``None`` if not training.)
     """
 
     def __init__(
@@ -259,13 +276,18 @@ class State(Serializable):
         # run_name
         run_name: str,
 
+        # device
+        device: Device,
+
         # stopping conditions
         max_duration: Optional[Union[str, Time[int]]] = None,
 
         # data configurations
-        grad_accum: int = 1,
+        grad_accum: Optional[int] = 1,
         eval_batch_split: int = 1,
-        auto_grad_accum: bool = False,
+        device_train_microbatch_size: Optional[int] = None,
+        auto_microbatching: bool = False,
+        using_device_microbatch_size: bool = True,
 
         # dataloaders
         train_dataloader: Optional[Iterable] = None,
@@ -276,6 +298,8 @@ class State(Serializable):
         dataloader: Optional[Iterable] = None,
         dataloader_label: Optional[str] = None,
         dataloader_len: Union[int, Time[int]] = -1,
+        dataset_state: Optional[Dict[str, Any]] = None,
+        dataset_resumption: Optional[Dict[str, Any]] = None,
 
         # precision
         precision: Union[str, Precision] = Precision.FP32,
@@ -290,23 +314,29 @@ class State(Serializable):
         algorithms: Optional[Union[Algorithm, Sequence[Algorithm]]] = None,
         callbacks: Optional[Union[Callback, Sequence[Callback]]] = None,
 
-        # deepspeed.
+        # Distributed training configs
         deepspeed_config: Optional[Dict[str, Any]] = None,
+        fsdp_config: Optional[Dict[str, Any]] = None,
     ):
         self.rank_zero_seed = rank_zero_seed
         self.model = model
         self.run_name = run_name
+        self.device = device
         self.grad_accum = grad_accum
         self.eval_batch_split = eval_batch_split
-        self.auto_grad_accum = auto_grad_accum
+        self.device_train_microbatch_size = device_train_microbatch_size
+        self.auto_microbatching = auto_microbatching
+        self.using_device_microbatch_size = using_device_microbatch_size
         self._dataloader_len = None
         self._dataloader = None
         self._dataloader_label = None
         self.set_dataloader(dataloader, dataloader_label, dataloader_len)
+        self.dataset_state = dataset_state
+        self.dataset_resumption = dataset_resumption or {}
         self._max_duration = None
         self.max_duration = max_duration
 
-        self.train_dataloader = train_dataloader
+        self._train_dataloader = train_dataloader
         self._evaluators = list(ensure_tuple(evaluators))
 
         self.timestamp = Timestamp()
@@ -328,6 +358,7 @@ class State(Serializable):
         self.profiler: Optional[Profiler] = None
 
         self.deepspeed_config = deepspeed_config
+        self.fsdp_config = fsdp_config
 
         # Set defaults for transient variables (to make pyright happy)
         self.batch: Any = None
@@ -351,10 +382,69 @@ class State(Serializable):
             'train_metrics',
             'eval_metrics',
             'run_name',
+            'dataset_state',
         ]
 
         self.train_metrics: Dict[str, Metric] = {}
         self.eval_metrics: Dict[str, Dict[str, Metric]] = {}
+        self.train_metric_values: Dict[str, float] = {}
+        self.eval_metric_values: Dict[str, float] = {}
+        self.total_loss_dict: Dict[str, float] = {}
+
+    def _dataset_of(self, dataloader: Optional[Union[Evaluator, DataSpec, DataLoader, Iterable]]) -> Optional[Dataset]:
+        """Get the dataset contained by the given dataloader-like object.
+
+        Args:
+            dataloader (Evaluator | DataSpec | DataLoader | Iterable, optional): The dataloader, wrapped dataloader, or
+                generic python iterable to get the dataset of, if applicable.
+
+        Returns:
+            Dataset: Its dataset, if there is one.
+        """
+        from composer.core.evaluator import Evaluator
+
+        # If it's None, no dataset for you.
+        if dataloader is None:
+            return None
+
+        # An Evaluator is a dataloader wrapped with metrics. Unwrap its dataloader.
+        if isinstance(dataloader, Evaluator):
+            dataloader = dataloader.dataloader
+
+        # A DataSpec is a dataloader wrapped with an on-device transform. Unwrap its dataloader.
+        if isinstance(dataloader, DataSpec):
+            dataloader = dataloader.dataloader
+
+        # If what we now have is an actual DataLoader, return its dataset. If not, return None.
+        if isinstance(dataloader, DataLoader):
+            return dataloader.dataset
+        else:
+            return None
+
+    @property
+    def train_dataloader(self) -> Optional[Union[Iterable, DataLoader]]:
+        """Get the train dataloader.
+
+        Returns:
+            Iterable | DataLoader, optional: The dataloader.
+        """
+        return self._train_dataloader
+
+    @train_dataloader.setter
+    def train_dataloader(self, train_dataloader: Optional[Union[Iterable, DataLoader]]):
+        """Set the train dataloader.
+
+        Args:
+            train_dataloader (Iterable | DataLoader, optional): The dataloader.
+        """
+        self._train_dataloader = train_dataloader
+        # Load dataset state from checkpoint when train_dataloader is set
+        if self.dataset_state:
+            dataset = self._dataset_of(self._train_dataloader)
+            if hasattr(dataset, 'load_state_dict'):
+                dataset.load_state_dict(self.dataset_state['train'])  # pyright: ignore
+                self.dataset_resumption['train'] = True
+            self.dataset_state['train'] = None
 
     @property
     def current_metrics(self):
@@ -487,6 +577,14 @@ class State(Serializable):
     @evaluators.setter
     def evaluators(self, evaluators: Union[Evaluator, Sequence[Evaluator]]):
         self._evaluators[:] = list(ensure_tuple(evaluators))
+        # Load dataset state from checkpoint when evaluators are set
+        if self.dataset_state:
+            state = self.dataset_state['eval']
+            for evaluator in self._evaluators:
+                dataset = self._dataset_of(evaluator)
+                if hasattr(dataset, 'load_state_dict') and evaluator.label in state:
+                    dataset.load_state_dict(state[evaluator.label])  # pyright: ignore
+            del self.dataset_state['eval']
 
     @property
     def deepspeed_enabled(self):
@@ -496,7 +594,7 @@ class State(Serializable):
     @property
     def fsdp_enabled(self):
         """Indicates if FSDP is enabled."""
-        if version.parse(torch.__version__) < version.parse('1.12.0'):
+        if version.parse(torch.__version__) < version.parse('1.13.0'):
             return False
         from torch.distributed.fsdp import FullyShardedDataParallel
         for module in self.model.modules():
@@ -504,12 +602,66 @@ class State(Serializable):
                 return True
         return False
 
+    def _get_integrations_state_dict(self) -> Dict[str, Any]:
+        """Gets a dictionary of information about integrations to store in the state dict.
+
+        This metadata is used for loading things from state dict that need to be done outside
+        of the normal Composer load path (e.g. HuggingFace model/tokenizer).
+        """
+        from composer.models import HuggingFaceModel
+        integrations = {}
+        if isinstance(self.model, HuggingFaceModel):
+            integrations['huggingface'] = self.model.get_metadata()
+        return integrations
+
+    def _get_state_metadata(self) -> Dict[str, Any]:
+        """Gets a dictionary of metadata to store in the state dict.
+
+        This metadata is used for checking compatibility between the current environment/setup
+        and the environment/setup that was used for the checkpoint that is being loaded in
+        """
+        metadata_dict = {}
+        metadata_dict['composer_env_info'] = get_composer_env_dict()
+
+        return metadata_dict
+
+    def _dataset_state_dict(self) -> Dict[str, Any]:
+        """Collect the state dict(s) of our train and eval dataset(s).
+
+        Returns:
+            Dict[str, Any]: The state dict(s).
+        """
+        obj = {
+            'train': None,
+            'eval': {},
+        }
+
+        dataset = self._dataset_of(self.train_dataloader)
+        if hasattr(dataset, 'state_dict'):
+            num_samples = int(self.timestamp.sample_in_epoch.value)
+            obj['train'] = dataset.state_dict(num_samples, True)  # pyright: ignore
+
+        for evaluator in self.evaluators:
+            dataset = self._dataset_of(evaluator)
+            if hasattr(dataset, 'state_dict'):
+                # Don't save eval sample because we do not checkpoint during eval.
+                obj['eval'][evaluator.label] = dataset.state_dict(0, True)  # pyright: ignore
+
+        return obj
+
     def state_dict(self) -> Dict[str, Any]:
+        """Collect the state dicts of our serializable attributes.
+
+        Returns:
+            Dict[str, Any]: The state dict.
+        """
         state_dict = {}
 
         for attribute_name in self.serialized_attributes:
             attribute_value = getattr(self, attribute_name)
-            if attribute_name == 'model':
+            if attribute_name == 'dataset_state':
+                serialized_value = self._dataset_state_dict()
+            elif attribute_name == 'model':
                 # Save model directly instead of by class name, since model may be wrapped by DistributedDataParallel
                 # If it is DDP wrapped, do not save the `module.` prefix, as that is an implmentation detail
                 with get_fsdp_rank0_cpu_save_context(
@@ -531,6 +683,9 @@ class State(Serializable):
                     serialized_value = {
                         type(obj).__qualname__: obj.state_dict() for obj in ensure_tuple(attribute_value)
                     }
+            elif attribute_name == 'algorithms':
+                # Store as list to preserve order in which algorithms were applied
+                serialized_value = [(type(obj).__qualname__, obj.state_dict()) for obj in ensure_tuple(attribute_value)]
             elif attribute_name in _STATE_DICT_SERIALIZED_ATTRIBUTES:
                 serialized_value = {type(obj).__qualname__: obj.state_dict() for obj in ensure_tuple(attribute_value)}
             else:
@@ -538,16 +693,141 @@ class State(Serializable):
 
             state_dict[attribute_name] = serialized_value
 
+        state_dict['integrations'] = self._get_integrations_state_dict()
+        state_dict['metadata'] = self._get_state_metadata()
+
         return state_dict
 
-    def load_model_state(self, state_dict: Dict[str, Any], strict: bool):
+    def _apply_required_algorithms(
+        self,
+        state_dict: Dict[str, Any],
+        logger: Logger,
+        exclude_algorithms: Optional[List[str]] = None,
+        algorithm_passes: Optional[List[AlgorithmPass]] = None,
+    ):
+        """Applies required algorithms which haven't been specified and aren't in the exclude list.
+
+        Args:
+            state_dict (Dict[str, Any]): State from checkpoint.
+            logger (Logger): Logger to use.
+            exclude_algorithms (List[str], optional): List of algorithm names to exclude. (default: ``None``)
+            algorithm_passes (List[AlgorithmPass], optional): A list of algorithm passes to apply to autoloaded algorithms
+                to sort them into the correct order. (default: ``None``)
+        """
+        # Don't try to autoload on old checkpoints
+        if not isinstance(state_dict['algorithms'], list):
+            return
+
+        import composer.algorithms as algorithms  # type: ignore imports used in `eval(representation)`
+
+        # Get repr of existing algorithms
+        current_algos = {}
+        for algo in self.algorithms:
+            if algo.required_on_load():
+                if type(algo) not in current_algos:
+                    current_algos[type(algo)] = []
+                current_algos[type(algo)].append(algo.__repr__())
+
+        # Gather algorithms to apply
+        missing_algos = set()
+        missing_algo_names = []
+        missing_algo_reprs = []
+        for algo_name, serialized_value in state_dict['algorithms']:
+            # Check if required algorithm
+            if hasattr(algorithms, algo_name) and getattr(algorithms, algo_name).required_on_load():
+                # Check that algorithm is not explicitly excluded by user
+                if exclude_algorithms is None or algo_name not in exclude_algorithms:
+                    try:
+                        algo = eval(f"algorithms.{serialized_value['repr']}")
+                    except:
+                        warnings.warn(
+                            textwrap.dedent(
+                                f"required_on_load algorithm {serialized_value['repr']} was enabled when training the "
+                                f'loaded checkpoint. Attempted to check its presence but recreating the algorithm '
+                                "failed. This may be due to a change in the algorithm's API. If this required_on_load "
+                                'algorithm is not properly specified, it may lead to unexpected behavior, including '
+                                'failing to load weights for some layers.'))
+                        continue
+                    # Raise warning if we are unable to safely autoapply
+                    if type(algo) in current_algos and not serialized_value['repr'] in current_algos[type(algo)]:
+                        warnings.warn(
+                            textwrap.dedent(
+                                f"required_on_load algorithm {serialized_value['repr']} was enabled when training the "
+                                f"loaded checkpoint but is now specified in the following forms: {', '.join(current_algos[type(algo)])}."
+                                'Potential parameter discrepancies for this required_on_load algorithm may lead to '
+                                'unexpected behavior, including failing to load weights for some layers.'))
+                    # Otherwise, queue algorithm to be autoappled
+                    elif type(algo) not in current_algos:
+                        missing_algos.add(algo)
+                        missing_algo_names.append(algo_name)
+                        missing_algo_reprs.append(serialized_value['repr'])
+                        self.algorithms.append(algo)
+
+        # Reorder algorithms based on algorithm_passes from engine
+        algo_list = self.algorithms
+        if algorithm_passes is not None:
+            for algo_pass in algorithm_passes:
+                algo_list = algo_pass(algo_list, Event.INIT)
+        # Raise ValueError if algorithm_passes order any checkpoint algorithm before an already
+        # applied user specified algorithm
+        encountered_ckpt_algo = False
+        for algo in algo_list:
+            if algo in missing_algos:
+                encountered_ckpt_algo = True
+            elif encountered_ckpt_algo:
+                raise ValueError(
+                    textwrap.dedent('The following algorithms were enabled when training this checkpoint '
+                                    f'and are required to successfully load it: {missing_algo_reprs}. '
+                                    'Attempted to autocreate and apply required algorithms, but at least one '
+                                    'of the loaded algorithms was ordered before a user specified algorithm '
+                                    'which has already been applied, preventing automatic application of '
+                                    'algorithms. If you wish to use pretrained weights and reinitialize '
+                                    'layers which have undergone surgery, the following algorithms may be '
+                                    'excluded using `load_exclude_algorithms`, e.g. '
+                                    f'`load_exclude_algorithms=[{missing_algo_names}]`.'))
+
+        try:
+            for algo in missing_algos:  # TODO: use compiled algorithm order
+                if algo.match(Event.INIT, self):
+                    algo.apply(Event.INIT, self, logger)
+                warnings.warn(
+                    textwrap.dedent(
+                        f'Automatically adding required_on_load algorithm {repr(algo)} to trainer, which was enabled '
+                        'when training the loaded checkpoint. If you wish to use pretrained weights and ignore '
+                        f'required_on_load algorithms, which may result in some weights failing to load, include {type(algo).__qualname__} '
+                        f"in `load_exclude_algorithms`, e.g. `load_exclude_algorithms=['{type(algo).__qualname__}']`."))
+        except Exception as e:
+            raise ValueError(
+                textwrap.dedent(
+                    'The following algorithms were enabled when training this checkpoint '
+                    f'and are required to successfully load it: {missing_algo_reprs}. '
+                    'Attempted to autocreate and apply required algorithms but an exception was '
+                    'encountered. If you wish to use pretrained weights and reinitialize layers which '
+                    'have undergone surgery, the following algorithms may be excluded using '
+                    f'`load_exclude_algorithms`, e.g. `load_exclude_algorithms=[{missing_algo_names}]`.')) from e
+
+    def load_model_state(
+        self,
+        state_dict: Dict[str, Any],
+        logger: Logger,
+        strict: bool,
+        exclude_algorithms: Optional[List[str]] = None,
+        algorithm_passes: Optional[List[AlgorithmPass]] = None,
+    ):
         """Loads the model's state from a ``state_dict``.
 
         Args:
             state_dict (Dict[str, Any]): The state dict, generated from a previous call to :meth:`state_dict`.
+            logger (Logger): The logger.
             strict (bool): Whether the keys (i.e., model parameter names) in the model state dict should
                 perfectly match the keys in the model instance.
+            exclude_algorithms (List[str], optional): List of algorithm names to exclude from autoloading. (default: ``None``)
+            algorithm_passes (List[AlgorithmPass], optional): A list of algorithm passes to apply to autoloaded algorithms
+                to sort them into the correct order. (default: ``None``)
         """
+        if 'algorithms' in state_dict:
+            self._apply_required_algorithms(state_dict, logger, exclude_algorithms, algorithm_passes)
+
         if state_dict.get('is_model_ddp', False) and not self.is_model_ddp:
             # This check is for backwards compatibility, as pre-v0.6.0 checkpoints serialized the state
             # with the `module.` prefix
@@ -556,11 +836,16 @@ class State(Serializable):
         with get_fsdp_rank0_cpu_save_context(self.model) if self.fsdp_enabled else contextlib.nullcontext():
             missing_keys, unexpected_keys = self.model.load_state_dict(state_dict['model'], strict=strict)
         if len(missing_keys) > 0:
-            logger.warning(f"Found these missing keys in the checkpoint: {', '.join(missing_keys)}")
+            log.warning(f"Found these missing keys in the checkpoint: {', '.join(missing_keys)}")
         if len(unexpected_keys) > 0:
-            logger.warning(f"Found these unexpected keys in the checkpoint: {', '.join(unexpected_keys)}")
+            log.warning(f"Found these unexpected keys in the checkpoint: {', '.join(unexpected_keys)}")
 
     def load_optim_state(self, state_dict: Dict[str, Any]):
+        """Load the optimizer state.
+
+        Args:
+            state_dict (Dict[str, Any]): The state to load.
+        """
         serialized_value = state_dict['optimizers']
         for target in ensure_tuple(self.optimizers):
             if type(target).__qualname__ not in serialized_value:
@@ -574,61 +859,82 @@ class State(Serializable):
             else:
                 target.load_state_dict(source)
 
-    def _verify_required_algorithms_enabled(self, state: Dict[str, Any]):
-        """Verifies all required algorithms are enabled when loading state.
+    def _load_dataset_state(self, obj: Dict[str, Any]) -> None:
+        """Load the dataset state.
 
         Args:
-            state (Dict[str, Any]): State from checkpoint.
+            obj (Dict[str, Any]): The state to load.
         """
-        import composer.algorithms as algorithms
+        self.dataset_state = obj
 
-        # Get repr of existing algorithms
-        state_algos = set()
-        for algo in self.algorithms:
-            state_algos.add(algo.__repr__())
+        dataset = self._dataset_of(self.train_dataloader)
+        if hasattr(dataset, 'load_state_dict'):
+            dataset.load_state_dict(obj['train'])  # pyright: ignore
+            obj['train'] = None
+            self.dataset_resumption['train'] = True
 
-        # Get repr of checkpoint algorithms
-        checkpoint_algos = set()
-        for algo, serialized_value in state['algorithms'].items():
-            try:
-                if getattr(algorithms, algo).required_on_load():
-                    checkpoint_algos.add(serialized_value['repr'])
-            except AttributeError:
-                logger.warning(
-                    f'Found algorithm of unknown type: {algo}. Skipping check for if it is required when loading checkpoint.'
-                )
+        for evaluator in self.evaluators:
+            dataset = self._dataset_of(evaluator)
+            if hasattr(dataset, 'load_state_dict') and evaluator.label in obj['eval']:
+                dataset.load_state_dict(obj['eval'][evaluator.label])  # pyright: ignore
+                del obj['eval'][evaluator.label]
+                if 'eval' not in self.dataset_resumption:
+                    self.dataset_resumption['eval'] = {}
+                # Note: We currently disable setting dataset_resumption for eval datasets,
+                # which means they have one sample fetched in _spin_dataloaders before training
+                # starts. This avoids "CUDA error: initialization error" -- its not clear why.
+                # self.dataset_resumption['eval'][evaluator.label] = True
 
-        missing_surgery_algos = []
-        for repr in checkpoint_algos:
-            if repr not in state_algos:
-                missing_surgery_algos.append(repr)
-
-        if len(missing_surgery_algos) > 0:
-            raise ValueError('The following surgery algorithms were enabled when training this checkpoint '
-                             f"and are required to successfully load it: {', '.join(missing_surgery_algos)}. "
-                             'If you wish to use pretrained weights and reinitialize layers which have '
-                             'undergone surgery, set `load_weights_only=True`.')
-
-    def load_state_dict(self, state: Dict[str, Any], strict: bool = False):
+    def load_state_dict(
+        self,
+        state: Dict[str, Any],
+        logger: Logger,
+        strict: bool = False,
+        exclude_algorithms: Optional[List[str]] = None,
+        algorithm_passes: Optional[List[AlgorithmPass]] = None,
+    ):
         """Loads the state.
 
         Args:
             state (Dict[str, Any]): object returned from call to :meth:`state_dict`.
+            logger (Logger): The logger.
             strict (bool): whether the keys in the ``state["model"]`` should perfectly match the keys in the
                 ``self.model``. Defaults to False.
+            exclude_algorithms (List[str], optional): List of algorithm names to exclude from autoloading. (default: ``None``)
+            algorithm_passes (List[AlgorithmPass], optional): A list of algorithm passes to apply to autoloaded algorithms
+                to sort them into the correct order. (default: ``None``)
         """
         state = _ensure_backwards_compatible_checkpointing(state)
 
-        if 'algorithms' in state:
-            self._verify_required_algorithms_enabled(state)
+        # Call load_model_state since it applies required algorithms
+        if 'model' in state:
+            self.load_model_state(
+                state,
+                logger,
+                strict=strict,
+                exclude_algorithms=exclude_algorithms,
+                algorithm_passes=algorithm_passes,
+            )
 
         for attribute_name, serialized_value in state.items():
-            if attribute_name not in self.serialized_attributes:
-                # It's possible some attributes we removed
+            # Skip removed attributes as well as algorithms and model, which was already loaded
+            if attribute_name not in self.serialized_attributes or attribute_name == 'model':
                 continue
 
-            if attribute_name == 'model':
-                self.load_model_state(state, strict=strict)
+            # Integrations are extra information about other libraries (e.g. huggingface) and not attributes to be loaded here
+            if attribute_name == 'integrations':
+                continue
+
+            # Skip metadata, which is not an attribute on State
+            if attribute_name == 'metadata':
+                continue
+
+            # Restructure algorithms serialized_value from list to dict
+            if attribute_name == 'algorithms' and isinstance(serialized_value, list):
+                serialized_value = {algo_name: algo_serialized for algo_name, algo_serialized in serialized_value}
+
+            if attribute_name == 'dataset_state':
+                self._load_dataset_state(serialized_value)
             elif attribute_name == 'optimizers':
                 self.load_optim_state(state)
             elif attribute_name in _STATE_DICT_SERIALIZED_ATTRIBUTES:
