@@ -12,8 +12,8 @@ import torch.utils.data
 from PIL import Image
 from torchvision.datasets import VisionDataset
 
-from composer.core.types import MemoryFormat
-from composer.utils.string_enum import StringEnum
+from composer.core import MemoryFormat
+from composer.utils import StringEnum
 
 __all__ = ['SyntheticDataType', 'SyntheticDataLabelType', 'SyntheticBatchPairDataset', 'SyntheticPILDataset']
 
@@ -62,7 +62,7 @@ class SyntheticBatchPairDataset(torch.utils.data.Dataset):
             on the GPU and eliminate PCI-e bandwidth with the dataloader. Set to ``'cpu'``
             to move data between host memory and the gpu on every batch. Default:
             ``'cpu'``.
-        memory_format (MemoryFormat, optional): Memory format for the sample pool.
+        memory_format (:class:`composer.core.MemoryFormat`, optional): Memory format for the sample pool.
             Default: `MemoryFormat.CONTIGUOUS_FORMAT`.
         transform (Callable, optional): Transform(s) to apply to data. Default: ``None``.
     """
