@@ -5,18 +5,21 @@
 import warnings
 
 from composer.utils.batch_helpers import batch_get, batch_set
-from composer.utils.checkpoint import load_checkpoint, save_checkpoint
-from composer.utils.collect_env import configure_excepthook, disable_env_report, enable_env_report, print_env
+from composer.utils.checkpoint import PartialFilePath, load_checkpoint, save_checkpoint
+from composer.utils.collect_env import (configure_excepthook, disable_env_report, enable_env_report,
+                                        get_composer_env_dict, print_env)
 from composer.utils.device import get_device, is_tpu_installed
-from composer.utils.file_helpers import (create_symlink_file, ensure_folder_has_no_conflicting_files,
+from composer.utils.file_helpers import (FORMAT_NAME_WITH_DIST_AND_TIME_TABLE, FORMAT_NAME_WITH_DIST_TABLE,
+                                         create_symlink_file, ensure_folder_has_no_conflicting_files,
                                          ensure_folder_is_empty, format_name_with_dist, format_name_with_dist_and_time,
-                                         get_file, is_tar)
+                                         get_file, is_tar, maybe_create_object_store_from_uri,
+                                         maybe_create_remote_uploader_downloader_from_uri, parse_uri)
 from composer.utils.import_helpers import MissingConditionalImportError, import_object
-from composer.utils.inference import export_for_inference, export_with_logger, quantize_dynamic
+from composer.utils.inference import ExportFormat, Transform, export_for_inference, export_with_logger, quantize_dynamic
 from composer.utils.iter_helpers import IteratorFileStream, ensure_tuple, map_collection
-from composer.utils.misc import is_model_deepspeed, is_model_fsdp, is_notebook, model_eval_mode
-from composer.utils.object_store import (LibcloudObjectStore, ObjectStore, ObjectStoreTransientError, S3ObjectStore,
-                                         SFTPObjectStore)
+from composer.utils.misc import get_free_tcp_port, is_model_deepspeed, is_model_fsdp, is_notebook, model_eval_mode
+from composer.utils.object_store import (LibcloudObjectStore, ObjectStore, ObjectStoreTransientError, OCIObjectStore,
+                                         S3ObjectStore, SFTPObjectStore)
 from composer.utils.retrying import retry
 from composer.utils.string_enum import StringEnum
 
@@ -30,25 +33,22 @@ def warn_yahp_deprecation() -> None:
         stacklevel=2)
 
 
-def warn_streaming_dataset_deprecation(old_version: int, new_version: int) -> None:
-    warnings.warn(
-        f'streaming dataset version {old_version} is deprecated and will be removed in the future. '
-        f'Please migrate to using streaming dataset version {new_version}',
-        DeprecationWarning,
-        stacklevel=2)
-
-
 __all__ = [
     'ensure_tuple',
+    'get_free_tcp_port',
     'map_collection',
     'IteratorFileStream',
+    'FORMAT_NAME_WITH_DIST_AND_TIME_TABLE',
+    'FORMAT_NAME_WITH_DIST_TABLE',
     'get_file',
+    'PartialFilePath',
     'create_symlink_file',
     'ObjectStore',
     'ObjectStoreTransientError',
     'LibcloudObjectStore',
     'S3ObjectStore',
     'SFTPObjectStore',
+    'OCIObjectStore',
     'MissingConditionalImportError',
     'import_object',
     'is_model_deepspeed',
@@ -65,14 +65,21 @@ __all__ = [
     'format_name_with_dist',
     'format_name_with_dist_and_time',
     'is_tar',
+    'maybe_create_object_store_from_uri',
+    'maybe_create_remote_uploader_downloader_from_uri',
+    'parse_uri',
     'batch_get',
     'batch_set',
     'configure_excepthook',
     'disable_env_report',
     'enable_env_report',
     'print_env',
+    'get_composer_env_dict',
     'retry',
     'model_eval_mode',
     'get_device',
     'is_tpu_installed',
+    'ExportFormat',
+    'Transform',
+    'export_with_logger',
 ]
